@@ -86,7 +86,7 @@
 #define KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED
-#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
+#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
 #endif
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x54c00
+#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x55100
 #  endif
 #endif
 
@@ -139,6 +139,12 @@
 #else
 #  define KNEWSTUFFCORE_DEPRECATED_VERSION_5_74(text)
 #endif
+
+#if KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE >= 0x54d00
+#  define KNEWSTUFFCORE_DEPRECATED_VERSION_5_77(text) KNEWSTUFFCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNEWSTUFFCORE_DEPRECATED_VERSION_5_77(text)
+#endif
 #define KNEWSTUFFCORE_DEPRECATED_VERSION_5(minor, text)      KNEWSTUFFCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KNEWSTUFFCORE_DEPRECATED_VERSION(major, minor, text) KNEWSTUFFCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KNEWSTUFFCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNEWSTUFFCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
